@@ -1,5 +1,5 @@
 import abc
-from typing import Any, Type, TypeVar
+from typing import TypeVar
 
 T = TypeVar("T")
 
@@ -17,14 +17,6 @@ class ApplicationContext(abc.ABC):
     def get_display_name(self) -> str:
         ...
 
-    @abc.abstractmethod
-    def get_bean(self, type: Type[T]) -> T:
-        ...
-
-    @abc.abstractmethod
-    def set_bean(self, bean: Any) -> None:
-        ...
-
     @property
     @abc.abstractmethod
     def debug(self) -> bool:
